==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/info/HeaderFooterType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for HeaderFooterType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HeaderFooterType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="font" type="{http://schema.webpdf.de/1.0/extraction/info}FontType"/&gt;
 *         &lt;element name="margin" type="{http://schema.webpdf.de/1.0/extraction/info}MarginType"/&gt;
 *         &lt;element name="header" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;attribute name="left" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="center" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="right" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="footer" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;attribute name="left" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="center" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="right" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="objectKey" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="page" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="color" type="{http://schema.webpdf.de/1.0/extraction/info}RgbColorType" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HeaderFooterType", propOrder = {
    "font",
    "margin",
    "header",
    "footer"
})
public class HeaderFooterType {

    @XmlElement(required = true)
    protected FontType font;
    @XmlElement(required = true)
    protected MarginType margin;
    protected HeaderFooterType.Header header;
    protected HeaderFooterType.Footer footer;
    @XmlAttribute(name = "objectKey")
    protected String objectKey;
    @XmlAttribute(name = "page")
    protected Integer page;
    @XmlAttribute(name = "color")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String color;

    /**
     * Gets the value of the font property.
     * 
     * @return
     *     possible object is
     *     {@link FontType }
     *     
     */
    public FontType getFont() {
        return font;
    }

    /**
     * Sets the value of the font property.
     * 
     * @param value
     *     allowed object is
     *     {@link FontType }
     *     
     */
    public void setFont(FontType value) {
        this.font = value;
    }

    public boolean isSetFont() {
        return (this.font!= null);
    }

    /**
     * Gets the value of the margin property.
     * 
     * @return
     *     possible object is
     *     {@link MarginType }
     *     
     */
    public MarginType getMargin() {
        return margin;
    }

    /**
     * Sets the value of the margin property.
     * 
     * @param value
     *     allowed object is
     *     {@link MarginType }
     *     
     */
    public void setMargin(MarginType value) {
        this.margin = value;
    }

    public boolean isSetMargin() {
        return (this.margin!= null);
    }

    /**
     * Gets the value of the header property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterType.Header }
     *     
     */
    public HeaderFooterType.Header getHeader() {
        return header;
    }

    /**
     * Sets the value of the header property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterType.Header }
     *     
     */
    public void setHeader(HeaderFooterType.Header value) {
        this.header = value;
    }

    public boolean isSetHeader() {
        return (this.header!= null);
    }

    /**
     * Gets the value of the footer property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterType.Footer }
     *     
     */
    public HeaderFooterType.Footer getFooter() {
        return footer;
    }

    /**
     * Sets the value of the footer property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterType.Footer }
     *     
     */
    public void setFooter(HeaderFooterType.Footer value) {
        this.footer = value;
    }

    public boolean isSetFooter() {
        return (this.footer!= null);
    }

    /**
     * Gets the value of the objectKey property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getObjectKey() {
        if (objectKey == null) {
            return "";
        } else {
            return objectKey;
        }
    }

    /**
     * Sets the value of the objectKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setObjectKey(String value) {
        this.objectKey = value;
    }

    public boolean isSetObjectKey() {
        return (this.objectKey!= null);
    }

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPage() {
        if (page == null) {
            return  0;
        } else {
            return page;
        }
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPage(int value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    public void unsetPage() {
        this.page = null;
    }

    /**
     * Gets the value of the color property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getColor() {
        return color;
    }

    /**
     * Sets the value of the color property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setColor(String value) {
        this.color = value;
    }

    public boolean isSetColor() {
        return (this.color!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;attribute name="left" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="center" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="right" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Footer {

        @XmlAttribute(name = "left")
        protected String left;
        @XmlAttribute(name = "center")
        protected String center;
        @XmlAttribute(name = "right")
        protected String right;

        /**
         * Gets the value of the left property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getLeft() {
            if (left == null) {
                return "";
            } else {
                return left;
            }
        }

        /**
         * Sets the value of the left property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setLeft(String value) {
            this.left = value;
        }

        public boolean isSetLeft() {
            return (this.left!= null);
        }

        /**
         * Gets the value of the center property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCenter() {
            if (center == null) {
                return "";
            } else {
                return center;
            }
        }

        /**
         * Sets the value of the center property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCenter(String value) {
            this.center = value;
        }

        public boolean isSetCenter() {
            return (this.center!= null);
        }

        /**
         * Gets the value of the right property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getRight() {
            if (right == null) {
                return "";
            } else {
                return right;
            }
        }

        /**
         * Sets the value of the right property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setRight(String value) {
            this.right = value;
        }

        public boolean isSetRight() {
            return (this.right!= null);
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;attribute name="left" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="center" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="right" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Header {

        @XmlAttribute(name = "left")
        protected String left;
        @XmlAttribute(name = "center")
        protected String center;
        @XmlAttribute(name = "right")
        protected String right;

        /**
         * Gets the value of the left property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getLeft() {
            if (left == null) {
                return "";
            } else {
                return left;
            }
        }

        /**
         * Sets the value of the left property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setLeft(String value) {
            this.left = value;
        }

        public boolean isSetLeft() {
            return (this.left!= null);
        }

        /**
         * Gets the value of the center property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCenter() {
            if (center == null) {
                return "";
            } else {
                return center;
            }
        }

        /**
         * Sets the value of the center property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCenter(String value) {
            this.center = value;
        }

        public boolean isSetCenter() {
            return (this.center!= null);
        }

        /**
         * Gets the value of the right property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getRight() {
            if (right == null) {
                return "";
            } else {
                return right;
            }
        }

        /**
         * Sets the value of the right property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setRight(String value) {
            this.right = value;
        }

        public boolean isSetRight() {
            return (this.right!= null);
        }

    }

}

==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/extraction/info/HeaderFooterType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;


/**
 * <p>Java class for HeaderFooterType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HeaderFooterType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="font" type="{http://schema.webpdf.de/1.0/extraction/info}FontType"/&gt;
 *         &lt;element name="margin" type="{http://schema.webpdf.de/1.0/extraction/info}MarginType"/&gt;
 *         &lt;element name="header" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;attribute name="left" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="center" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="right" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="footer" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;attribute name="left" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="center" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="right" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="objectKey" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="page" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="color" type="{http://schema.webpdf.de/1.0/extraction/info}RgbColorType" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HeaderFooterType", propOrder = {
    "font",
    "margin",
    "header",
    "footer"
})
@JsonIgnoreProperties(ignoreUnknown = true)
public class HeaderFooterType {

    @XmlElement(required = true)
    protected FontType font;
    @XmlElement(required = true)
    protected MarginType margin;
    protected HeaderFooterType.Header header;
    protected HeaderFooterType.Footer footer;
    @XmlAttribute(name = "objectKey")
    protected String objectKey;
    @XmlAttribute(name = "page")
    protected Integer page;
    @XmlAttribute(name = "color")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String color;

    /**
     * Gets the value of the font property.
     * 
     * @return
     *     possible object is
     *     {@link FontType }
     *     
     */
    public FontType getFont() {
        return font;
    }

    /**
     * Sets the value of the font property.
     * 
     * @param value
     *     allowed object is
     *     {@link FontType }
     *     
     */
    public void setFont(FontType value) {
        this.font = value;
    }

    public boolean isSetFont() {
        return (this.font!= null);
    }

    /**
     * Gets the value of the margin property.
     * 
     * @return
     *     possible object is
     *     {@link MarginType }
     *     
     */
    public MarginType getMargin() {
        return margin;
    }

    /**
     * Sets the value of the margin property.
     * 
     * @param value
     *     allowed object is
     *     {@link MarginType }
     *     
     */
    public void setMargin(MarginType value) {
        this.margin = value;
    }

    public boolean isSetMargin() {
        return (this.margin!= null);
    }

    /**
     * Gets the value of the header property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterType.Header }
     *     
     */
    public HeaderFooterType.Header getHeader() {
        return header;
    }

    /**
     * Sets the value of the header property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterType.Header }
     *     
     */
    public void setHeader(HeaderFooterType.Header value) {
        this.header = value;
    }

    public boolean isSetHeader() {
        return (this.header!= null);
    }

    /**
     * Gets the value of the footer property.
     * 
     * @return
     *     possible object is
     *     {@link HeaderFooterType.Footer }
     *     
     */
    public HeaderFooterType.Footer getFooter() {
        return footer;
    }

    /**
     * Sets the value of the footer property.
     * 
     * @param value
     *     allowed object is
     *     {@link HeaderFooterType.Footer }
     *     
     */
    public void setFooter(HeaderFooterType.Footer value) {
        this.footer = value;
    }

    public boolean isSetFooter() {
        return (this.footer!= null);
    }

    /**
     * Gets the value of the objectKey property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getObjectKey() {
        if (objectKey == null) {
            return "";
        } else {
            return objectKey;
        }
    }

    /**
     * Sets the value of the objectKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setObjectKey(String value) {
        this.objectKey = value;
    }

    public boolean isSetObjectKey() {
        return (this.objectKey!= null);
    }

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPage() {
        if (page == null) {
            return  0;
        } else {
            return page;
        }
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPage(int value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    public void unsetPage() {
        this.page = null;
    }

    /**
     * Gets the value of the color property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getColor() {
        return color;
    }

    /**
     * Sets the value of the color property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setColor(String value) {
        this.color = value;
    }

    public boolean isSetColor() {
        return (this.color!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;attribute name="left" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="center" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="right" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Footer {

        @XmlAttribute(name = "left")
        protected String left;
        @XmlAttribute(name = "center")
        protected String center;
        @XmlAttribute(name = "right")
        protected String right;

        /**
         * Gets the value of the left property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getLeft() {
            if (left == null) {
                return "";
            } else {
                return left;
            }
        }

        /**
         * Sets the value of the left property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setLeft(String value) {
            this.left = value;
        }

        public boolean isSetLeft() {
            return (this.left!= null);
        }

        /**
         * Gets the value of the center property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCenter() {
            if (center == null) {
                return "";
            } else {
                return center;
            }
        }

        /**
         * Sets the value of the center property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCenter(String value) {
            this.center = value;
        }

        public boolean isSetCenter() {
            return (this.center!= null);
        }

        /**
         * Gets the value of the right property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getRight() {
            if (right == null) {
                return "";
            } else {
                return right;
            }
        }

        /**
         * Sets the value of the right property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setRight(String value) {
            this.right = value;
        }

        public boolean isSetRight() {
            return (this.right!= null);
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;attribute name="left" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="center" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="right" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Header {

        @XmlAttribute(name = "left")
        protected String left;
        @XmlAttribute(name = "center")
        protected String center;
        @XmlAttribute(name = "right")
        protected String right;

        /**
         * Gets the value of the left property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getLeft() {
            if (left == null) {
                return "";
            } else {
                return left;
            }
        }

        /**
         * Sets the value of the left property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setLeft(String value) {
            this.left = value;
        }

        public boolean isSetLeft() {
            return (this.left!= null);
        }

        /**
         * Gets the value of the center property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCenter() {
            if (center == null) {
                return "";
            } else {
                return center;
            }
        }

        /**
         * Sets the value of the center property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCenter(String value) {
            this.center = value;
        }

        public boolean isSetCenter() {
            return (this.center!= null);
        }

        /**
         * Gets the value of the right property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getRight() {
            if (right == null) {
                return "";
            } else {
                return right;
            }
        }

        /**
         * Sets the value of the right property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setRight(String value) {
            this.right = value;
        }

        public boolean isSetRight() {
            return (this.right!= null);
        }

    }

}
